@@ -14,32 +14,30 @@
 
 -- To create the database:
 --   CREATE DATABASE blog;
---   GRANT ALL PRIVILEGES ON blog.* TO 'blog'@'localhost' IDENTIFIED BY 'blog';
+--   CREATE USER blog WITH PASSWORD 'blog';
+--   GRANT ALL ON DATABASE blog TO blog;
 --
 -- To reload the tables:
---   mysql --user=blog --password=blog --database=blog < schema.sql
-
-SET SESSION storage_engine = "InnoDB";
-SET SESSION time_zone = "+0:00";
-ALTER DATABASE CHARACTER SET "utf8";
-
-DROP TABLE IF EXISTS entries;
-CREATE TABLE entries (
-    id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
-    author_id INT NOT NULL REFERENCES authors(id),
-    slug VARCHAR(100) NOT NULL UNIQUE,
-    title VARCHAR(512) NOT NULL,
-    markdown MEDIUMTEXT NOT NULL,
-    html MEDIUMTEXT NOT NULL,
-    published DATETIME NOT NULL,
-    updated TIMESTAMP NOT NULL,
-    KEY (published)
-);
+--   psql -U blog -d blog < schema.sql
 
 DROP TABLE IF EXISTS authors;
 CREATE TABLE authors (
-    id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
+    id SERIAL PRIMARY KEY,
     email VARCHAR(100) NOT NULL UNIQUE,
     name VARCHAR(100) NOT NULL,
     hashed_password VARCHAR(100) NOT NULL
 );
+
+DROP TABLE IF EXISTS entries;
+CREATE TABLE entries (
+    id SERIAL PRIMARY KEY,
+    author_id INT NOT NULL REFERENCES authors(id),
+    slug VARCHAR(100) NOT NULL UNIQUE,
+    title VARCHAR(512) NOT NULL,
+    markdown TEXT NOT NULL,
+    html TEXT NOT NULL,
+    published TIMESTAMP NOT NULL,
+    updated TIMESTAMP NOT NULL
+);
+
+CREATE INDEX ON entries (published);
